@@ -146,13 +146,15 @@ PropList::PropList(const hid_t plist_id) : IdComponent()
         case H5I_DATASPACE:
         case H5I_DATASET:
         case H5I_ATTR:
-        case H5I_REFERENCE:
         case H5I_VFL:
+        case H5I_VOL:
         case H5I_ERROR_CLASS:
         case H5I_ERROR_MSG:
         case H5I_ERROR_STACK:
         case H5I_NTYPES:
         case H5I_UNINIT:
+        case H5I_MAP:
+        case H5I_SPACE_SEL_ITER:
         default:
             id = H5P_DEFAULT;
             break;
@@ -546,7 +548,7 @@ PropList::getPropSize(const H5std_string &name) const
 // Function:    PropList::getClassName
 ///\brief       Return the name of a generic property list class.
 ///\return      A string containing the class name, if success, otherwise,
-///             an empty string.
+///             a NULL string.
 // Programmer:  Binh-Minh Ribler - April, 2004
 //--------------------------------------------------------------------------
 H5std_string
@@ -560,9 +562,8 @@ PropList::getClassName() const
         return (class_name);
     }
     else
-        return "";
+        return 0;
 }
-
 //--------------------------------------------------------------------------
 // Function:    PropList::getNumProps
 ///\brief       Returns the number of properties in this property list or class.
