@@ -11,13 +11,13 @@
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  *
  ******
-*/
+ */
 
 #include "H5f90.h"
 #include "H5Eprivate.h"
@@ -44,29 +44,30 @@
  * HISTORY
  *
  * SOURCE
-*/
+ */
 int_f
-h5acreate_c(hid_t_f *obj_id, _fcd name, size_t_f *namelen, hid_t_f *type_id,
-    hid_t_f *space_id, hid_t_f *crt_prp, hid_t_f *aapl, hid_t_f *attr_id)
+h5acreate_c(hid_t_f *obj_id, _fcd name, size_t_f *namelen, hid_t_f *type_id, hid_t_f *space_id,
+            hid_t_f *crt_prp, hid_t_f *aapl, hid_t_f *attr_id)
 /*******/
 {
-    char *c_name = NULL;        /* Buffer to hold C string */
-    int_f ret_value = 0;        /* Return value */
+    char *c_name    = NULL; /* Buffer to hold C string */
+    int_f ret_value = 0;    /* Return value */
 
-     /*
-      * Convert FORTRAN name to C name
-      */
-    if(NULL == (c_name = HD5f2cstring(name, (size_t)*namelen)))
+    /*
+     * Convert FORTRAN name to C name
+     */
+    if (NULL == (c_name = HD5f2cstring(name, (size_t)*namelen)))
         HGOTO_DONE(FAIL);
 
-     /*
-      * Call H5Acreate2 function.
-      */
-    if((*attr_id = (hid_t_f)H5Acreate2((hid_t)*obj_id, c_name, (hid_t)*type_id, (hid_t)*space_id, (hid_t)*crt_prp, (hid_t)*aapl)) < 0)
+    /*
+     * Call H5Acreate2 function.
+     */
+    if ((*attr_id = (hid_t_f)H5Acreate2((hid_t)*obj_id, c_name, (hid_t)*type_id, (hid_t)*space_id,
+                                        (hid_t)*crt_prp, (hid_t)*aapl)) < 0)
         HGOTO_DONE(FAIL);
 
 done:
-    if(c_name)
+    if (c_name)
         HDfree(c_name);
     return ret_value;
 }
@@ -88,28 +89,28 @@ done:
  * HISTORY
  *
  * SOURCE
-*/
+ */
 int_f
-h5adelete_c (hid_t_f *obj_id, _fcd name, size_t_f *namelen)
+h5adelete_c(hid_t_f *obj_id, _fcd name, size_t_f *namelen)
 /******/
 {
-    char *c_name = NULL;        /* Buffer to hold C string */
-    int_f ret_value = 0;        /* Return value */
+    char *c_name    = NULL; /* Buffer to hold C string */
+    int_f ret_value = 0;    /* Return value */
 
-     /*
-      * Convert FORTRAN name to C name
-      */
-     if((c_name = HD5f2cstring(name, (size_t)*namelen)) == NULL)
+    /*
+     * Convert FORTRAN name to C name
+     */
+    if ((c_name = HD5f2cstring(name, (size_t)*namelen)) == NULL)
         HGOTO_DONE(FAIL);
 
-     /*
-      * Call H5Adelete function.
-      */
-     if(H5Adelete((hid_t)*obj_id, c_name) < 0)
-         HGOTO_DONE(FAIL);
+    /*
+     * Call H5Adelete function.
+     */
+    if (H5Adelete((hid_t)*obj_id, c_name) < 0)
+        HGOTO_DONE(FAIL);
 
 done:
-    if(c_name)
+    if (c_name)
         HDfree(c_name);
 
     return ret_value;
@@ -132,25 +133,25 @@ done:
  * HISTORY
  *
  * SOURCE
-*/
+ */
 int_f
-h5aget_num_attrs_c (hid_t_f *obj_id, int_f *attr_num)
+h5aget_num_attrs_c(hid_t_f *obj_id, int_f *attr_num)
 /******/
 {
-    H5O_info_t oinfo;           /* Object info */
-    int_f ret_value = 0;        /* Return value */
+    H5O_info2_t oinfo;         /* Object info */
+    int_f       ret_value = 0; /* Return value */
 
     /*
      * Call H5Oget_info function.
      */
-    if(H5Oget_info((hid_t)*obj_id, &oinfo) < 0)
+    if (H5Oget_info3((hid_t)*obj_id, &oinfo, H5O_INFO_NUM_ATTRS) < 0)
         HGOTO_DONE(FAIL);
 
     /* Set number of attributes */
     *attr_num = (int_f)oinfo.num_attrs;
 
 done:
-     return ret_value;
+    return ret_value;
 }
 
 /****if* H5Af/h5aget_name_c
@@ -171,40 +172,40 @@ done:
  * HISTORY
  *
  * SOURCE
-*/
+ */
 int_f
 h5aget_name_c(hid_t_f *attr_id, size_t_f *bufsize, _fcd buf)
 /******/
 {
-  size_t c_bufsize;
-  char *c_buf=NULL;           /* Buffer to hold C string */
-  int_f ret_value=0;          /* Return value */
+    size_t c_bufsize;
+    char * c_buf     = NULL; /* Buffer to hold C string */
+    int_f  ret_value = 0;    /* Return value */
 
-  c_bufsize = (size_t)*bufsize+1;
+    c_bufsize = (size_t)*bufsize + 1;
 
-  /*
-   * Allocate buffer to hold name of an attribute
-   */
-  if(NULL == (c_buf = (char *)HDmalloc(c_bufsize)))
-    HGOTO_DONE(FAIL);
+    /*
+     * Allocate buffer to hold name of an attribute
+     */
+    if (NULL == (c_buf = (char *)HDmalloc(c_bufsize)))
+        HGOTO_DONE(FAIL);
 
-  /*
-   * Call H5Aget_name function
-   */
-  if ((ret_value = (int_f)H5Aget_name((hid_t)*attr_id, c_bufsize, c_buf)) < 0)
-    HGOTO_DONE(FAIL);
+    /*
+     * Call H5Aget_name function
+     */
+    if ((ret_value = (int_f)H5Aget_name((hid_t)*attr_id, c_bufsize, c_buf)) < 0)
+        HGOTO_DONE(FAIL);
 
-  /*
-   * Convert C name to FORTRAN and place it in the given buffer
-   */
-  HD5packFstring(c_buf, _fcdtocp(buf), c_bufsize-1);
+    /*
+     * Convert C name to FORTRAN and place it in the given buffer
+     */
+    HD5packFstring(c_buf, _fcdtocp(buf), c_bufsize - 1);
 
 done:
-  if(c_buf) HDfree(c_buf);
-  return ret_value;
+    if (c_buf)
+        HDfree(c_buf);
+    return ret_value;
 }
 
-
 /****if* H5Af/h5arename_by_name_c
  * NAME
  *  h5arename_by_name_c
@@ -230,39 +231,38 @@ done:
  * HISTORY
  * N/A
  * SOURCE
-*/
+ */
 
 int_f
-h5arename_by_name_c( hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen,
-		      _fcd old_attr_name, size_t_f *old_attr_namelen,
-		      _fcd new_attr_name, size_t_f *new_attr_namelen,
-		      hid_t_f *lapl_id )
+h5arename_by_name_c(hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen, _fcd old_attr_name,
+                    size_t_f *old_attr_namelen, _fcd new_attr_name, size_t_f *new_attr_namelen,
+                    hid_t_f *lapl_id)
 /******/
 {
-    char *c_obj_name = NULL;          /* Buffer to hold C string */
-    char *c_old_attr_name = NULL;     /* Buffer to hold C string */
-    char *c_new_attr_name = NULL;     /* Buffer to hold C string */
-    int_f ret_value=0;          /* Return value */
-     /*
-      * Convert FORTRAN name to C name
-      */
-    if((c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)) == NULL)
-      HGOTO_DONE(FAIL);
-    if((c_old_attr_name = HD5f2cstring(old_attr_name, (size_t)*old_attr_namelen)) == NULL)
-      HGOTO_DONE(FAIL);
-    if((c_new_attr_name = HD5f2cstring(new_attr_name, (size_t)*new_attr_namelen)) == NULL)
-      HGOTO_DONE(FAIL);
+    char *c_obj_name      = NULL; /* Buffer to hold C string */
+    char *c_old_attr_name = NULL; /* Buffer to hold C string */
+    char *c_new_attr_name = NULL; /* Buffer to hold C string */
+    int_f ret_value       = 0;    /* Return value */
+                                  /*
+                                   * Convert FORTRAN name to C name
+                                   */
+    if ((c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)) == NULL)
+        HGOTO_DONE(FAIL);
+    if ((c_old_attr_name = HD5f2cstring(old_attr_name, (size_t)*old_attr_namelen)) == NULL)
+        HGOTO_DONE(FAIL);
+    if ((c_new_attr_name = HD5f2cstring(new_attr_name, (size_t)*new_attr_namelen)) == NULL)
+        HGOTO_DONE(FAIL);
 
-    if(H5Arename_by_name((hid_t)*loc_id,c_obj_name,c_old_attr_name,c_new_attr_name,(hid_t)*lapl_id) < 0)
+    if (H5Arename_by_name((hid_t)*loc_id, c_obj_name, c_old_attr_name, c_new_attr_name, (hid_t)*lapl_id) < 0)
         HGOTO_DONE(FAIL);
 
 done:
-    if(c_obj_name)
-      HDfree(c_obj_name);
-    if(c_old_attr_name)
-      HDfree(c_old_attr_name);
-    if(c_new_attr_name)
-      HDfree(c_new_attr_name);
+    if (c_obj_name)
+        HDfree(c_obj_name);
+    if (c_old_attr_name)
+        HDfree(c_old_attr_name);
+    if (c_new_attr_name)
+        HDfree(c_new_attr_name);
     return ret_value;
 }
 
@@ -286,28 +286,28 @@ done:
  * HISTORY
  *
  * SOURCE
-*/
+ */
 int_f
-h5aopen_c (hid_t_f *obj_id, _fcd attr_name, size_t_f *attr_namelen, hid_t_f *aapl_id, hid_t_f *attr_id)
+h5aopen_c(hid_t_f *obj_id, _fcd attr_name, size_t_f *attr_namelen, hid_t_f *aapl_id, hid_t_f *attr_id)
 /******/
 {
-    char *c_attr_name = NULL;          /* Buffer to hold C string */
-    int_f ret_value = 0;          /* Return value */
+    char *c_attr_name = NULL; /* Buffer to hold C string */
+    int_f ret_value   = 0;    /* Return value */
 
-     /*
-      * Convert FORTRAN name to C name
-      */
-     if((c_attr_name = HD5f2cstring(attr_name, (size_t)*attr_namelen)) == NULL)
+    /*
+     * Convert FORTRAN name to C name
+     */
+    if ((c_attr_name = HD5f2cstring(attr_name, (size_t)*attr_namelen)) == NULL)
         HGOTO_DONE(FAIL);
-     /*
-      * Call H5Aopen function.
-      */
+    /*
+     * Call H5Aopen function.
+     */
 
-      if((*attr_id = (hid_t_f)H5Aopen((hid_t)*obj_id, c_attr_name, (hid_t)*aapl_id)) < 0)
-	HGOTO_DONE(FAIL);
+    if ((*attr_id = (hid_t_f)H5Aopen((hid_t)*obj_id, c_attr_name, (hid_t)*aapl_id)) < 0)
+        HGOTO_DONE(FAIL);
 
 done:
-    if(c_attr_name)
+    if (c_attr_name)
         HDfree(c_attr_name);
     return ret_value;
 }
@@ -334,33 +334,34 @@ done:
  * HISTORY
  * N/A
  * SOURCE
-*/
+ */
 int_f
-h5adelete_by_name_c (hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen, _fcd attr_name, size_t_f *attr_namelen, hid_t_f *lapl_id)
+h5adelete_by_name_c(hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen, _fcd attr_name,
+                    size_t_f *attr_namelen, hid_t_f *lapl_id)
 /******/
 {
-    char *c_obj_name = NULL;          /* Buffer to hold C string */
-    char *c_attr_name = NULL;         /* Buffer to hold C string */
-    int_f ret_value = 0;          /* Return value */
+    char *c_obj_name  = NULL; /* Buffer to hold C string */
+    char *c_attr_name = NULL; /* Buffer to hold C string */
+    int_f ret_value   = 0;    /* Return value */
 
-     /*
-      * Convert FORTRAN name to C name
-      */
-    if((c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)) == NULL)
-      HGOTO_DONE(FAIL);
-    if((c_attr_name = HD5f2cstring(attr_name, (size_t)*attr_namelen)) == NULL)
-      HGOTO_DONE(FAIL);
+    /*
+     * Convert FORTRAN name to C name
+     */
+    if ((c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)) == NULL)
+        HGOTO_DONE(FAIL);
+    if ((c_attr_name = HD5f2cstring(attr_name, (size_t)*attr_namelen)) == NULL)
+        HGOTO_DONE(FAIL);
 
-     /*
-      * Call H5Adelete_by_name function.
-      */
-    if(H5Adelete_by_name((hid_t)*loc_id, c_obj_name, c_attr_name, (hid_t)*lapl_id) < 0)
-      HGOTO_DONE(FAIL);
+    /*
+     * Call H5Adelete_by_name function.
+     */
+    if (H5Adelete_by_name((hid_t)*loc_id, c_obj_name, c_attr_name, (hid_t)*lapl_id) < 0)
+        HGOTO_DONE(FAIL);
 
 done:
-    if(c_attr_name)
+    if (c_attr_name)
         HDfree(c_attr_name);
-    if(c_obj_name)
+    if (c_obj_name)
         HDfree(c_obj_name);
     return ret_value;
 }
@@ -387,29 +388,30 @@ done:
  * HISTORY
  * N/A
  * SOURCE
-*/
+ */
 int_f
-h5adelete_by_idx_c (hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen,
-		     int_f *idx_type, int_f *order, hsize_t_f *n, hid_t_f *lapl_id)
+h5adelete_by_idx_c(hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen, int_f *idx_type, int_f *order,
+                   hsize_t_f *n, hid_t_f *lapl_id)
 /******/
 {
-    char *c_obj_name = NULL;          /* Buffer to hold C string */
-    int_f ret_value = 0;          /* Return value */
+    char *c_obj_name = NULL; /* Buffer to hold C string */
+    int_f ret_value  = 0;    /* Return value */
 
-     /*
-      * Convert FORTRAN name to C name
-      */
-    if(NULL == (c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)))
+    /*
+     * Convert FORTRAN name to C name
+     */
+    if (NULL == (c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)))
         HGOTO_DONE(FAIL)
 
-     /*
-      * Call H5Adelete_by_name function.
-      */
-    if(H5Adelete_by_idx((hid_t)*loc_id, c_obj_name, (H5_index_t)*idx_type, (H5_iter_order_t)*order, (hsize_t)*n, (hid_t)*lapl_id) < 0)
+    /*
+     * Call H5Adelete_by_name function.
+     */
+    if (H5Adelete_by_idx((hid_t)*loc_id, c_obj_name, (H5_index_t)*idx_type, (H5_iter_order_t)*order,
+                         (hsize_t)*n, (hid_t)*lapl_id) < 0)
         HGOTO_DONE(FAIL)
 
 done:
-    if(c_obj_name)
+    if (c_obj_name)
         HDfree(c_obj_name);
 
     return ret_value;
@@ -457,51 +459,50 @@ done:
  * HISTORY
  * N/A
  * SOURCE
-*/
+ */
 int_f
-h5aget_name_by_idx_c (hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen,
-		       int_f *idx_type, int_f *order, hsize_t_f *n, _fcd name,
-		       size_t_f *size, hid_t_f *lapl_id)
+h5aget_name_by_idx_c(hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen, int_f *idx_type, int_f *order,
+                     hsize_t_f *n, _fcd name, size_t_f *size, hid_t_f *lapl_id)
 /******/
 {
-    char *c_obj_name = NULL;          /* Buffer to hold C string */
+    char *  c_obj_name = NULL; /* Buffer to hold C string */
     ssize_t c_size;
-    size_t c_buf_size;
-    char *c_buf = NULL;
-    int_f ret_value = 0;          /* Return value */
+    size_t  c_buf_size;
+    char *  c_buf     = NULL;
+    int_f   ret_value = 0; /* Return value */
 
     /*
      * Convert FORTRAN name to C name
      */
-    if(NULL == (c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)))
+    if (NULL == (c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)))
         HGOTO_DONE(FAIL)
 
     /*
      * Allocate buffer to hold name of an attribute
      */
     c_buf_size = (size_t)*size + 1;
-    if(NULL == (c_buf = (char *)HDmalloc(c_buf_size)))
+    if (NULL == (c_buf = (char *)HDmalloc(c_buf_size)))
         HGOTO_DONE(FAIL)
 
-     /*
-      * Call H5Aget_name_by_idx function.
-      */
-     c_size = H5Aget_name_by_idx((hid_t)*loc_id, c_obj_name, (H5_index_t)*idx_type, (H5_iter_order_t)*order, (hsize_t)*n, c_buf, c_buf_size,(hid_t)*lapl_id);
-     if(c_size < 0)
+    /*
+     * Call H5Aget_name_by_idx function.
+     */
+    c_size = H5Aget_name_by_idx((hid_t)*loc_id, c_obj_name, (H5_index_t)*idx_type, (H5_iter_order_t)*order,
+                                (hsize_t)*n, c_buf, c_buf_size, (hid_t)*lapl_id);
+    if (c_size < 0)
         HGOTO_DONE(FAIL)
 
-
-     /*
-      * Convert C name to FORTRAN and place it in the given buffer
-      */
-     HD5packFstring(c_buf, _fcdtocp(name), c_buf_size - 1);
-     *size = (size_t_f)c_size;
+    /*
+     * Convert C name to FORTRAN and place it in the given buffer
+     */
+    HD5packFstring(c_buf, _fcdtocp(name), c_buf_size - 1);
+    *size = (size_t_f)c_size;
 
 done:
-   if(c_obj_name)
-       HDfree(c_obj_name);
-   if(c_buf)
-       HDfree(c_buf);
+    if (c_obj_name)
+        HDfree(c_obj_name);
+    if (c_buf)
+        HDfree(c_buf);
     return ret_value;
 }
 
@@ -540,29 +541,31 @@ done:
  * HISTORY
  * N/A
  * SOURCE
-*/
+ */
 int_f
-h5aopen_by_idx_c (hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen,
-		   int_f *idx_type, int_f *order, hsize_t_f *n, hid_t_f *aapl_id, hid_t_f *lapl_id, hid_t_f *attr_id )
+h5aopen_by_idx_c(hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen, int_f *idx_type, int_f *order,
+                 hsize_t_f *n, hid_t_f *aapl_id, hid_t_f *lapl_id, hid_t_f *attr_id)
 /******/
 {
-    char *c_obj_name = NULL;          /* Buffer to hold C string */
-    int_f ret_value = 0;          /* Return value */
+    char *c_obj_name = NULL; /* Buffer to hold C string */
+    int_f ret_value  = 0;    /* Return value */
 
     /*
      * Convert FORTRAN name to C name
      */
-    if(NULL == (c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)))
+    if (NULL == (c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)))
         HGOTO_DONE(FAIL)
 
-     /*
-      * Call H5Aopen_by_idx function.
-      */
-    if((*attr_id = (hid_t_f)H5Aopen_by_idx((hid_t)*loc_id, c_obj_name, (H5_index_t)*idx_type, (H5_iter_order_t)*order, (hsize_t)*n, (hid_t)*aapl_id, (hid_t)*lapl_id)) < 0)
+    /*
+     * Call H5Aopen_by_idx function.
+     */
+    if ((*attr_id = (hid_t_f)H5Aopen_by_idx((hid_t)*loc_id, c_obj_name, (H5_index_t)*idx_type,
+                                            (H5_iter_order_t)*order, (hsize_t)*n, (hid_t)*aapl_id,
+                                            (hid_t)*lapl_id)) < 0)
         HGOTO_DONE(FAIL)
 
 done:
-    if(c_obj_name)
+    if (c_obj_name)
         HDfree(c_obj_name);
 
     return ret_value;
@@ -590,30 +593,29 @@ done:
  * HISTORY
  * N/A
  * SOURCE
-*/
+ */
 int_f
-h5aget_info_c (hid_t_f *loc_id, int_f *corder_valid, int_f *corder,
-		int_f *cset, hsize_t_f *data_size )
+h5aget_info_c(hid_t_f *loc_id, int_f *corder_valid, int_f *corder, int_f *cset, hsize_t_f *data_size)
 /******/
 {
 
-    int_f ret_value = 0;          /* Return value */
+    int_f      ret_value = 0; /* Return value */
     H5A_info_t ainfo;
 
-
-     /*
-      * Call H5Aget_info function.
-      */
-    if(H5Aget_info((hid_t)*loc_id,&ainfo) < 0)
-      HGOTO_DONE(FAIL);
+    /*
+     * Call H5Aget_info function.
+     */
+    if (H5Aget_info((hid_t)*loc_id, &ainfo) < 0)
+        HGOTO_DONE(FAIL);
 
     /* Unpack the structure */
 
     *corder_valid = 0;
-    if(ainfo.corder_valid > 0) *corder_valid = 1;
+    if (ainfo.corder_valid > 0)
+        *corder_valid = 1;
 
-    *corder = (int_f)ainfo.corder;
-    *cset = (int_f)ainfo.cset;
+    *corder    = (int_f)ainfo.corder;
+    *cset      = (int_f)ainfo.cset;
     *data_size = (hsize_t_f)ainfo.data_size;
 
 done:
@@ -659,41 +661,40 @@ done:
  * HISTORY
  * N/A
  * SOURCE
-*/
+ */
 int_f
-h5aget_info_by_idx_c (hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen,
-		int_f *idx_type, int_f *order, hsize_t_f *n, hid_t_f *lapl_id,
-		int_f *corder_valid, int_f *corder,
-		int_f *cset, hsize_t_f *data_size )
+h5aget_info_by_idx_c(hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen, int_f *idx_type, int_f *order,
+                     hsize_t_f *n, hid_t_f *lapl_id, int_f *corder_valid, int_f *corder, int_f *cset,
+                     hsize_t_f *data_size)
 /******/
 {
-    char *c_obj_name = NULL;          /* Buffer to hold C string */
+    char *     c_obj_name = NULL; /* Buffer to hold C string */
     H5A_info_t ainfo;
-    int_f ret_value = 0;          /* Return value */
+    int_f      ret_value = 0; /* Return value */
 
     /*
      * Convert FORTRAN name to C name
      */
-    if(NULL == (c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)))
+    if (NULL == (c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)))
         HGOTO_DONE(FAIL)
 
-     /*
-      * Call H5Ainfo_by_idx function.
-      */
-    if(H5Aget_info_by_idx((hid_t)*loc_id, c_obj_name, (H5_index_t)*idx_type, (H5_iter_order_t)*order, (hsize_t)*n,
-            &ainfo, (hid_t)*lapl_id) < 0)
-      HGOTO_DONE(FAIL)
+    /*
+     * Call H5Ainfo_by_idx function.
+     */
+    if (H5Aget_info_by_idx((hid_t)*loc_id, c_obj_name, (H5_index_t)*idx_type, (H5_iter_order_t)*order,
+                           (hsize_t)*n, &ainfo, (hid_t)*lapl_id) < 0)
+        HGOTO_DONE(FAIL)
 
     /* Unpack the structure */
     *corder_valid = 0;
-    if(ainfo.corder_valid > 0)
+    if (ainfo.corder_valid > 0)
         *corder_valid = 1;
-    *corder = (int_f)ainfo.corder;
-    *cset = (int_f)ainfo.cset;
+    *corder    = (int_f)ainfo.corder;
+    *cset      = (int_f)ainfo.cset;
     *data_size = (hsize_t_f)ainfo.data_size;
 
 done:
-    if(c_obj_name)
+    if (c_obj_name)
         HDfree(c_obj_name);
 
     return ret_value;
@@ -726,45 +727,44 @@ done:
  * HISTORY
  * N/A
  * SOURCE
-*/
+ */
 int_f
-h5aget_info_by_name_c (hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen,
-			_fcd attr_name, size_t_f *attr_namelen, hid_t_f *lapl_id,
-			int_f *corder_valid, int_f *corder,
-			int_f *cset, hsize_t_f *data_size )
+h5aget_info_by_name_c(hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen, _fcd attr_name,
+                      size_t_f *attr_namelen, hid_t_f *lapl_id, int_f *corder_valid, int_f *corder,
+                      int_f *cset, hsize_t_f *data_size)
 /******/
 {
-    char *c_obj_name = NULL;          /* Buffer to hold C string */
-    char *c_attr_name = NULL;          /* Buffer to hold C string */
+    char *     c_obj_name  = NULL; /* Buffer to hold C string */
+    char *     c_attr_name = NULL; /* Buffer to hold C string */
     H5A_info_t ainfo;
-    int_f ret_value = 0;          /* Return value */
+    int_f      ret_value = 0; /* Return value */
 
     /*
      * Convert FORTRAN name to C name
      */
-    if(NULL == (c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)))
+    if (NULL == (c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)))
         HGOTO_DONE(FAIL)
-    if(NULL == (c_attr_name = HD5f2cstring(attr_name, (size_t)*attr_namelen)))
+    if (NULL == (c_attr_name = HD5f2cstring(attr_name, (size_t)*attr_namelen)))
         HGOTO_DONE(FAIL)
 
-     /*
-      * Call H5Ainfo_by_name function.
-      */
-    if(H5Aget_info_by_name((hid_t)*loc_id, c_obj_name, c_attr_name, &ainfo, (hid_t)*lapl_id) < 0)
+    /*
+     * Call H5Ainfo_by_name function.
+     */
+    if (H5Aget_info_by_name((hid_t)*loc_id, c_obj_name, c_attr_name, &ainfo, (hid_t)*lapl_id) < 0)
         HGOTO_DONE(FAIL)
 
     /* Unpack the structure */
     *corder_valid = 0;
-    if(ainfo.corder_valid > 0)
+    if (ainfo.corder_valid > 0)
         *corder_valid = 1;
-    *corder = (int_f)ainfo.corder;
-    *cset = (int_f)ainfo.cset;
+    *corder    = (int_f)ainfo.corder;
+    *cset      = (int_f)ainfo.cset;
     *data_size = (hsize_t_f)ainfo.data_size;
 
 done:
-    if(c_obj_name)
+    if (c_obj_name)
         HDfree(c_obj_name);
-    if(c_attr_name)
+    if (c_attr_name)
         HDfree(c_attr_name);
 
     return ret_value;
@@ -803,37 +803,37 @@ done:
  * SOURCE
 */
 int_f
-h5acreate_by_name_c(hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen,
-		     _fcd attr_name, size_t_f *attr_namelen,  hid_t_f *type_id,
-		     hid_t_f *space_id, hid_t_f *acpl_id, hid_t_f *aapl_id,
-		     hid_t_f *lapl_id, hid_t_f *attr_id )
+h5acreate_by_name_c(hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen, _fcd attr_name,
+                    size_t_f *attr_namelen, hid_t_f *type_id, hid_t_f *space_id, hid_t_f *acpl_id,
+                    hid_t_f *aapl_id, hid_t_f *lapl_id, hid_t_f *attr_id)
 /******/
 {
-  char *c_obj_name = NULL;      /* Buffer to hold C string */
-  char *c_attr_name = NULL;     /* Buffer to hold C string */
-  int_f ret_value = 0;          /* Return value */
+    char *c_obj_name  = NULL; /* Buffer to hold C string */
+    char *c_attr_name = NULL; /* Buffer to hold C string */
+    int_f ret_value   = 0;    /* Return value */
 
-  /*
-   * Convert FORTRAN name to C name
-   */
-  if((c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)) == NULL)
-    HGOTO_DONE(FAIL);
-  if((c_attr_name = HD5f2cstring(attr_name, (size_t)*attr_namelen)) == NULL)
-    HGOTO_DONE(FAIL);
+    /*
+     * Convert FORTRAN name to C name
+     */
+    if ((c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)) == NULL)
+        HGOTO_DONE(FAIL);
+    if ((c_attr_name = HD5f2cstring(attr_name, (size_t)*attr_namelen)) == NULL)
+        HGOTO_DONE(FAIL);
 
-  /*
-   * Call H5Acreate_by_name function.
-   */
-  if((*attr_id = (hid_t_f)H5Acreate_by_name((hid_t)*loc_id, c_obj_name, c_attr_name,
-					    (hid_t)*type_id, (hid_t)*space_id,(hid_t)*acpl_id,(hid_t)*aapl_id,(hid_t)*lapl_id )) < 0)
-    HGOTO_DONE(FAIL);
+    /*
+     * Call H5Acreate_by_name function.
+     */
+    if ((*attr_id = (hid_t_f)H5Acreate_by_name((hid_t)*loc_id, c_obj_name, c_attr_name, (hid_t)*type_id,
+                                               (hid_t)*space_id, (hid_t)*acpl_id, (hid_t)*aapl_id,
+                                               (hid_t)*lapl_id)) < 0)
+        HGOTO_DONE(FAIL);
 
 done:
-  if(c_obj_name)
-    HDfree(c_obj_name);
-  if(c_attr_name)
-    HDfree(c_attr_name);
-  return ret_value;
+    if (c_obj_name)
+        HDfree(c_obj_name);
+    if (c_attr_name)
+        HDfree(c_attr_name);
+    return ret_value;
 }
 
 /****if* H5Af/h5aexists_c
@@ -856,28 +856,28 @@ done:
  * HISTORY
  *
  * SOURCE
-*/
+ */
 int_f
-h5aexists_c (hid_t_f *obj_id, _fcd name, size_t_f *namelen, hid_t_f *attr_exists)
+h5aexists_c(hid_t_f *obj_id, _fcd name, size_t_f *namelen, hid_t_f *attr_exists)
 /******/
 {
-  char *c_name = NULL;          /* Buffer to hold C string */
-  int_f ret_value = 0;          /* Return value */
+    char *c_name    = NULL; /* Buffer to hold C string */
+    int_f ret_value = 0;    /* Return value */
 
-  /*
-   * Convert FORTRAN name to C name
-   */
-  if((c_name = HD5f2cstring(name, (size_t)*namelen)) == NULL)
-    HGOTO_DONE(FAIL);
+    /*
+     * Convert FORTRAN name to C name
+     */
+    if ((c_name = HD5f2cstring(name, (size_t)*namelen)) == NULL)
+        HGOTO_DONE(FAIL);
 
-  /*
-   * Call H5Aexists function.
-   */
-  if((*attr_exists = (hid_t_f)H5Aexists((hid_t)*obj_id, c_name)) < 0)
-         HGOTO_DONE(FAIL);
+    /*
+     * Call H5Aexists function.
+     */
+    if ((*attr_exists = (hid_t_f)H5Aexists((hid_t)*obj_id, c_name)) < 0)
+        HGOTO_DONE(FAIL);
 
 done:
-    if(c_name)
+    if (c_name)
         HDfree(c_name);
     return ret_value;
 }
@@ -904,34 +904,35 @@ done:
  * HISTORY
  *
  * SOURCE
-*/
+ */
 int_f
-h5aexists_by_name_c (hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen, _fcd attr_name, size_t_f *attr_namelen,
-		      hid_t_f *lapl_id, int_f *attr_exists)
+h5aexists_by_name_c(hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen, _fcd attr_name,
+                    size_t_f *attr_namelen, hid_t_f *lapl_id, int_f *attr_exists)
 /******/
 {
-  char *c_obj_name = NULL;          /* Buffer to hold object name C string */
-  char *c_attr_name = NULL;          /* Buffer to hold attribute name C string */
-  int_f ret_value = 0;          /* Return value */
+    char *c_obj_name  = NULL; /* Buffer to hold object name C string */
+    char *c_attr_name = NULL; /* Buffer to hold attribute name C string */
+    int_f ret_value   = 0;    /* Return value */
 
-  /*
-   * Convert FORTRAN name to C name
-   */
-  if((c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)) == NULL)
-    HGOTO_DONE(FAIL);
-  if((c_attr_name = HD5f2cstring(attr_name, (size_t)*attr_namelen)) == NULL)
-    HGOTO_DONE(FAIL);
+    /*
+     * Convert FORTRAN name to C name
+     */
+    if ((c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)) == NULL)
+        HGOTO_DONE(FAIL);
+    if ((c_attr_name = HD5f2cstring(attr_name, (size_t)*attr_namelen)) == NULL)
+        HGOTO_DONE(FAIL);
 
-  /*
-   * Call H5Aexists_by_name function.
-   */
-  if((*attr_exists = (int_f)H5Aexists_by_name((hid_t)*loc_id, c_obj_name, c_attr_name, (hid_t)*lapl_id)) < 0)
-         HGOTO_DONE(FAIL);
+    /*
+     * Call H5Aexists_by_name function.
+     */
+    if ((*attr_exists = (int_f)H5Aexists_by_name((hid_t)*loc_id, c_obj_name, c_attr_name, (hid_t)*lapl_id)) <
+        0)
+        HGOTO_DONE(FAIL);
 
 done:
-    if(c_obj_name)
+    if (c_obj_name)
         HDfree(c_obj_name);
-    if(c_attr_name)
+    if (c_attr_name)
         HDfree(c_attr_name);
     return ret_value;
 }
@@ -959,36 +960,37 @@ done:
  * HISTORY
  *
  * SOURCE
-*/
+ */
 int_f
-h5aopen_by_name_c (hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen, _fcd attr_name, size_t_f *attr_namelen,
-		    hid_t_f *aapl_id, hid_t_f *lapl_id, hid_t_f *attr_id)
+h5aopen_by_name_c(hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen, _fcd attr_name,
+                  size_t_f *attr_namelen, hid_t_f *aapl_id, hid_t_f *lapl_id, hid_t_f *attr_id)
 /******/
 {
-  char *c_obj_name = NULL;          /* Buffer to hold object name C string */
-  char *c_attr_name = NULL;          /* Buffer to hold attribute name C string */
-  int_f ret_value = 0;          /* Return value */
+    char *c_obj_name  = NULL; /* Buffer to hold object name C string */
+    char *c_attr_name = NULL; /* Buffer to hold attribute name C string */
+    int_f ret_value   = 0;    /* Return value */
 
-  /*
-   * Convert FORTRAN name to C name
-   */
-  if((c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)) == NULL)
-    HGOTO_DONE(FAIL);
-  if((c_attr_name = HD5f2cstring(attr_name, (size_t)*attr_namelen)) == NULL)
-    HGOTO_DONE(FAIL);
+    /*
+     * Convert FORTRAN name to C name
+     */
+    if ((c_obj_name = HD5f2cstring(obj_name, (size_t)*obj_namelen)) == NULL)
+        HGOTO_DONE(FAIL);
+    if ((c_attr_name = HD5f2cstring(attr_name, (size_t)*attr_namelen)) == NULL)
+        HGOTO_DONE(FAIL);
 
-  /*
-   * Call H5Aopen function.
-   */
-  if((*attr_id = (hid_t_f)H5Aopen_by_name((hid_t)*loc_id, c_obj_name, c_attr_name, (hid_t)*aapl_id, (hid_t)*lapl_id)) < 0)
-    HGOTO_DONE(FAIL);
+    /*
+     * Call H5Aopen function.
+     */
+    if ((*attr_id = (hid_t_f)H5Aopen_by_name((hid_t)*loc_id, c_obj_name, c_attr_name, (hid_t)*aapl_id,
+                                             (hid_t)*lapl_id)) < 0)
+        HGOTO_DONE(FAIL);
 
- done:
-  if(c_obj_name)
-    HDfree(c_obj_name);
-  if(c_attr_name)
-    HDfree(c_attr_name);
-  return ret_value;
+done:
+    if (c_obj_name)
+        HDfree(c_obj_name);
+    if (c_attr_name)
+        HDfree(c_attr_name);
+    return ret_value;
 }
 
 /****if* H5Af/h5arename_c
@@ -1012,33 +1014,32 @@ h5aopen_by_name_c (hid_t_f *loc_id, _fcd obj_name, size_t_f *obj_namelen, _fcd a
  * HISTORY
  * N/A
  * SOURCE
-*/
+ */
 
 int_f
-h5arename_c( hid_t_f *loc_id,
-		      _fcd old_attr_name, size_t_f *old_attr_namelen,
-		      _fcd new_attr_name, size_t_f *new_attr_namelen)
+h5arename_c(hid_t_f *loc_id, _fcd old_attr_name, size_t_f *old_attr_namelen, _fcd new_attr_name,
+            size_t_f *new_attr_namelen)
 /******/
 {
-  char *c_old_attr_name = NULL;     /* Buffer to hold C string */
-  char *c_new_attr_name = NULL;     /* Buffer to hold C string */
-  int_f ret_value=0;          /* Return value */
-  /*
-   * Convert FORTRAN name to C name
-   */
-  if((c_old_attr_name = HD5f2cstring(old_attr_name, (size_t)*old_attr_namelen)) == NULL)
-    HGOTO_DONE(FAIL);
-  if((c_new_attr_name = HD5f2cstring(new_attr_name, (size_t)*new_attr_namelen)) == NULL)
-    HGOTO_DONE(FAIL);
+    char *c_old_attr_name = NULL; /* Buffer to hold C string */
+    char *c_new_attr_name = NULL; /* Buffer to hold C string */
+    int_f ret_value       = 0;    /* Return value */
+    /*
+     * Convert FORTRAN name to C name
+     */
+    if ((c_old_attr_name = HD5f2cstring(old_attr_name, (size_t)*old_attr_namelen)) == NULL)
+        HGOTO_DONE(FAIL);
+    if ((c_new_attr_name = HD5f2cstring(new_attr_name, (size_t)*new_attr_namelen)) == NULL)
+        HGOTO_DONE(FAIL);
 
-    if(H5Arename((hid_t)*loc_id,c_old_attr_name,c_new_attr_name) < 0)
+    if (H5Arename((hid_t)*loc_id, c_old_attr_name, c_new_attr_name) < 0)
         HGOTO_DONE(FAIL);
 
 done:
-    if(c_old_attr_name)
-      HDfree(c_old_attr_name);
-    if(c_new_attr_name)
-      HDfree(c_new_attr_name);
+    if (c_old_attr_name)
+        HDfree(c_old_attr_name);
+    if (c_new_attr_name)
+        HDfree(c_new_attr_name);
     return ret_value;
 }
 /****if* H5Af/h5awrite_f_c
@@ -1059,19 +1060,20 @@ done:
  *
  *
  * SOURCE
-*/
+ */
 int_f
-h5awrite_f_c (hid_t_f *attr_id, hid_t_f *mem_type_id, void *buf)
+h5awrite_f_c(hid_t_f *attr_id, hid_t_f *mem_type_id, void *buf)
 /******/
 {
-  int ret_value = -1;
-  herr_t ret;
+    int    ret_value = -1;
+    herr_t ret;
 
-  ret = H5Awrite( (hid_t)*attr_id, (hid_t)*mem_type_id, buf);
+    ret = H5Awrite((hid_t)*attr_id, (hid_t)*mem_type_id, buf);
 
-  if (ret < 0) return ret_value;
-  ret_value = 0;
-  return ret_value;
+    if (ret < 0)
+        return ret_value;
+    ret_value = 0;
+    return ret_value;
 }
 
 /****if* H5Af/h5aread_f_c
@@ -1092,18 +1094,18 @@ h5awrite_f_c (hid_t_f *attr_id, hid_t_f *mem_type_id, void *buf)
  *
  *
  * SOURCE
-*/
+ */
 int_f
-h5aread_f_c (hid_t_f *attr_id, hid_t_f *mem_type_id, void *buf)
+h5aread_f_c(hid_t_f *attr_id, hid_t_f *mem_type_id, void *buf)
 /******/
 {
-  int ret_value = -1;
-  herr_t ret;
+    int    ret_value = -1;
+    herr_t ret;
 
-  ret = H5Aread( (hid_t)*attr_id, (hid_t)*mem_type_id, buf);
+    ret = H5Aread((hid_t)*attr_id, (hid_t)*mem_type_id, buf);
 
-  if (ret < 0) return ret_value;
-  ret_value = 0;
-  return ret_value;
+    if (ret < 0)
+        return ret_value;
+    ret_value = 0;
+    return ret_value;
 }
-
