@@ -1,12 +1,11 @@
 /* * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * *
  * Copyright by The HDF Group.                                               *
- * Copyright by the Board of Trustees of the University of Illinois.         *
  * All rights reserved.                                                      *
  *                                                                           *
  * This file is part of HDF5.  The full HDF5 copyright notice, including     *
  * terms governing use, modification, and redistribution, is contained in    *
  * the COPYING file, which can be found at the root of the source code       *
- * distribution tree, or in https://support.hdfgroup.org/ftp/HDF5/releases.  *
+ * distribution tree, or in https://www.hdfgroup.org/licenses.               *
  * If you do not have access to either file, you may request a copy from     *
  * help@hdfgroup.org.                                                        *
  * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * * */
@@ -24,11 +23,14 @@ import org.junit.After;
 import org.junit.Before;
 import org.junit.Rule;
 import org.junit.Test;
+import org.junit.Ignore;
 import org.junit.rules.TestName;
 
 public class TestH5Edefault {
     @Rule public TestName testname = new TestName();
 
+    public static final int ERRSTACK_CNT = 6;
+
     @Before
     public void H5Eset_default_stack() {
         assertTrue("H5 open ids is 0",H5.getOpenIDCount()==0);
@@ -53,19 +55,28 @@ public class TestH5Edefault {
         H5.H5Eprint2(-1, null);
     }
 
-    @Test
+    @Ignore
     public void testH5Eprint() {
-        try {
-            H5.H5Fopen("test", 0, 1);
-        }
-        catch (Throwable err) {
-        }
-        try {
-            H5.H5Eprint2(HDF5Constants.H5E_DEFAULT, null);
-        }
-        catch (Throwable err) {
-            err.printStackTrace();
-            fail("H5.H5Eprint: " + err);
+        /*
+        * If HDF5_VOL_CONNECTOR is set, this might not be the
+        * native connector and the error stack might be different.
+        * Only check for the specific error stack if the native
+        * connector is being used.
+        */
+        String connector = System.getenv("HDF5_VOL_CONNECTOR");
+        if (connector == null) {
+            try {
+                H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
+            }
+            catch (Throwable err) {
+            }
+            try {
+                H5.H5Eprint2(HDF5Constants.H5E_DEFAULT, null);
+            }
+            catch (Throwable err) {
+                err.printStackTrace();
+                fail("H5.H5Eprint: " + err);
+            }
         }
     }
 
@@ -73,17 +84,18 @@ public class TestH5Edefault {
     public void testH5Eget_current_stack() {
         long num_msg = -1;
         long num_msg_default = -1;
+        long saved_num_msg = -1;
         long stack_id = -1;
         long stack_id_default = HDF5Constants.H5E_DEFAULT;
         try {
-            H5.H5Fopen("test", 0, 1);
+            H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
         }
         catch (Throwable err) {
             //default stack id will be different after exception
             stack_id_default = HDF5Constants.H5E_DEFAULT;
             //err.printStackTrace(); //This will clear the error stack
         }
-        // Verify we have the correct number of messages
+        // Verify we have messages on the error stack
         try {
             num_msg_default = H5.H5Eget_num(stack_id_default);
         }
@@ -91,10 +103,10 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eget_current_stack: " + err);
         }
-        assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg_default,
-                num_msg_default == 3);
+        assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg_default, num_msg_default > 0);
+        saved_num_msg = num_msg_default;
 
-        //Save a copy of the current stack and clears the current stack
+        // Save a copy of the current stack and clear the current stack
         try {
             stack_id = H5.H5Eget_current_stack();
         }
@@ -102,12 +114,10 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eget_current_stack: " + err);
         }
-        assertFalse("H5.H5Eget_current_stack: get_current_stack - "
-                + stack_id, stack_id < 0);
-        assertFalse("H5.H5Eget_current_stack: get_current_stack - "
-                + stack_id, stack_id == stack_id_default);
+        assertFalse("H5.H5Eget_current_stack: get_current_stack - " + stack_id, stack_id < 0);
+        assertFalse("H5.H5Eget_current_stack: get_current_stack - " + stack_id, stack_id == stack_id_default);
 
-        // Verify we have the correct number of messages
+        // Verify the default stack is empty
         try {
             num_msg_default = H5.H5Eget_num(stack_id_default);
         }
@@ -115,10 +125,9 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eget_current_stack: " + err);
         }
-        assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg_default,
-                num_msg_default == 0);
+        assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg_default, num_msg_default == 0);
 
-        //Verify the copy has the correct number of messages
+        // Verify the copy has the same number of messages as the original
         try {
             num_msg = H5.H5Eget_num(stack_id);
         }
@@ -126,8 +135,7 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eget_current_stack: " + err);
         }
-        assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg,
-                num_msg == 3);
+        assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg, num_msg == saved_num_msg);
 
         try {
             H5.H5Eclose_stack(stack_id);
@@ -142,15 +150,16 @@ public class TestH5Edefault {
     public void testH5Eget_current_stack_pop() {
         long num_msg = -1;
         long num_msg_default = -1;
+        long saved_num_msg = -1;
         long stack_id = -1;
         try {
-            H5.H5Fopen("test", 0, 1);
+            H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
         }
         catch (Throwable err) {
             //err.printStackTrace(); //This will clear the error stack
         }
 
-        // Verify we have the correct number of messages
+        // Verify there are error messages on the stack and save it
         try {
             num_msg_default = H5.H5Eget_num(HDF5Constants.H5E_DEFAULT);
         }
@@ -158,10 +167,10 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eget_current_stack: " + err);
         }
-        assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg_default,
-                num_msg_default == 3);
+        assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg_default, num_msg_default > 0);
+        saved_num_msg = num_msg_default;
 
-        //Save a copy of the current stack and clears the current stack
+        // Save a copy of the current stack and clear the current stack
         try {
             stack_id = H5.H5Eget_current_stack();
         }
@@ -169,12 +178,10 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eget_current_stack: " + err);
         }
-        assertFalse("H5.H5Eget_current_stack: get_current_stack - "
-                + stack_id, stack_id < 0);
-        assertFalse("H5.H5Eget_current_stack: get_current_stack - "
-                + stack_id, stack_id == HDF5Constants.H5E_DEFAULT);
+        assertFalse("H5.H5Eget_current_stack: get_current_stack - " + stack_id, stack_id < 0);
+        assertFalse("H5.H5Eget_current_stack: get_current_stack - " + stack_id, stack_id == HDF5Constants.H5E_DEFAULT);
 
-        // Verify we have the correct number of messages
+        // Verify the stack is empty
         try {
             num_msg_default = H5.H5Eget_num(HDF5Constants.H5E_DEFAULT);
         }
@@ -182,10 +189,9 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eget_current_stack: " + err);
         }
-        assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg_default,
-                num_msg_default == 0);
+        assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg_default, num_msg_default == 0);
 
-        //Verify the copy has the correct number of messages
+        // Verify the copy has the correct number of messages
         try {
             num_msg = H5.H5Eget_num(stack_id);
         }
@@ -193,18 +199,17 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eget_current_stack: " + err);
         }
-        assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg,
-                num_msg == 3);
+        assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg, num_msg == saved_num_msg);
 
-        //Generate errors on default stack
+        // Generate errors on default stack
         try {
-            H5.H5Fopen("test", 0, 1);
+            H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
         }
         catch (Throwable err) {
             //err.printStackTrace(); //This will clear the error stack
         }
 
-        // Verify we have the correct number of messages
+        // Verify we have a nonzero number of messages and save it
         try {
             num_msg_default = H5.H5Eget_num(HDF5Constants.H5E_DEFAULT);
         }
@@ -212,10 +217,10 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eget_current_stack: " + err);
         }
-        assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg_default,
-                num_msg_default == 3);
+        assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg_default, num_msg_default > 0);
+        saved_num_msg = num_msg;
 
-        //Remove one message from the current stack
+        // Remove one message from the current stack
         try {
             H5.H5Epop(HDF5Constants.H5E_DEFAULT, 1);
             num_msg_default = H5.H5Eget_num(HDF5Constants.H5E_DEFAULT);
@@ -224,10 +229,9 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eget_current_stack: " + err);
         }
-        assertTrue("H5.H5Eget_current_stack: pop #:" + num_msg_default,
-                num_msg_default == 2);
+        assertTrue("H5.H5Eget_current_stack: pop #:" + num_msg_default, num_msg_default == saved_num_msg - 1);
 
-        //Verify the copy still has the correct number of messages
+        // Verify the copy still has the old number of messages
         try {
             num_msg = H5.H5Eget_num(stack_id);
         }
@@ -235,8 +239,7 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eget_current_stack: " + err);
         }
-        assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg,
-                num_msg == 3);
+        assertTrue("H5.H5Eget_current_stack: get_num #:" + num_msg, num_msg == saved_num_msg);
     }
 
     @Test(expected = IllegalArgumentException.class)
@@ -249,7 +252,7 @@ public class TestH5Edefault {
         H5.H5Eget_class_name(-1);
     }
 
-    @Test(expected = IllegalArgumentException.class)
+    @Test(expected = HDF5LibraryException.class)
     public void testH5Eget_class_name_invalid_classname() throws Throwable {
         H5.H5Eget_class_name(HDF5Constants.H5E_DEFAULT);
     }
@@ -291,14 +294,17 @@ public class TestH5Edefault {
     public void testH5Eset_current_stack() {
         long num_msg = -1;
         long stack_id = -1;
+        long saved_num_msg = -1;
+
+        // Generate errors on the default stack
         try {
-            H5.H5Fopen("test", 0, 1);
+            H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
         }
         catch (Throwable err) {
             //err.printStackTrace(); //This will clear the error stack
         }
 
-        // Verify we have the correct number of messages
+        // Verify we have a nonzero number of messages and save it
         try {
             num_msg = H5.H5Eget_num(HDF5Constants.H5E_DEFAULT);
         }
@@ -306,10 +312,10 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eset_current_stack: " + err);
         }
-        assertTrue("H5.H5Eset_current_stack: get_num #:" + num_msg,
-                    num_msg == 3);
+        assertTrue("H5.H5Eset_current_stack: get_num #:" + num_msg, num_msg > 0);
+        saved_num_msg = num_msg;
 
-        //Save a copy of the current stack
+        // Save a copy of the current stack
         try {
             stack_id = H5.H5Eget_current_stack();
         }
@@ -317,12 +323,10 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eset_current_stack: " + err);
         }
-        assertFalse("H5.H5Eset_current_stack: get_current_stack - "
-                    + stack_id, stack_id < 0);
-        assertFalse("H5.H5Eset_current_stack: get_current_stack - "
-                + stack_id, stack_id == HDF5Constants.H5E_DEFAULT);
+        assertFalse("H5.H5Eset_current_stack: get_current_stack - " + stack_id, stack_id < 0);
+        assertFalse("H5.H5Eset_current_stack: get_current_stack - " + stack_id, stack_id == HDF5Constants.H5E_DEFAULT);
 
-        //Verify the copy has the correct number of messages
+        // Verify the copy has the same number of messages as the original stack
         try {
             num_msg = H5.H5Eget_num(stack_id);
         }
@@ -330,18 +334,17 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eset_current_stack: " + err);
         }
-        assertTrue("H5.H5Eset_current_stack: get_num #:" + num_msg,
-                    num_msg == 3);
+        assertTrue("H5.H5Eset_current_stack: get_num #:" + num_msg, num_msg == saved_num_msg);
 
-        //Generate errors on default stack
+        // Generate errors on default stack (again, in the same way)
         try {
-            H5.H5Fopen("test", 0, 1);
+            H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
         }
         catch (Throwable err) {
             //err.printStackTrace(); //This will clear the error stack
         }
 
-        // Verify we have the correct number of messages
+        // Verify we have the same number of messages as before
         try {
             num_msg = H5.H5Eget_num(HDF5Constants.H5E_DEFAULT);
         }
@@ -349,10 +352,9 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eget_current_stack: " + err);
         }
-        assertTrue("H5.H5Eset_current_stack: get_num #:" + num_msg,
-                num_msg == 3);
+        assertTrue("H5.H5Eset_current_stack: get_num #:" + num_msg, num_msg == saved_num_msg);
 
-        //Remove one message from the current stack
+        // Remove one message from the current stack
         try {
             H5.H5Epop(HDF5Constants.H5E_DEFAULT, 1);
             num_msg = H5.H5Eget_num(HDF5Constants.H5E_DEFAULT);
@@ -361,10 +363,9 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eset_current_stack: " + err);
         }
-        assertTrue("H5.H5Eset_current_stack: pop #:" + num_msg,
-                    num_msg == 2);
+        assertTrue("H5.H5Eset_current_stack: pop #:" + num_msg, num_msg == saved_num_msg - 1);
 
-        //Verify the copy still has the correct number of messages
+        // Verify the copy still has the correct number of messages
         try {
             num_msg = H5.H5Eget_num(stack_id);
         }
@@ -372,9 +373,9 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eset_current_stack: " + err);
         }
-        assertTrue("H5.H5Eset_current_stack: get_num #:" + num_msg,
-                    num_msg == 3);
+        assertTrue("H5.H5Eset_current_stack: get_num #:" + num_msg, num_msg == saved_num_msg);
 
+        // Set the current stack to be the default and try that again
         try {
             H5.H5Eset_current_stack(stack_id);
             num_msg = H5.H5Eget_num(HDF5Constants.H5E_DEFAULT);
@@ -383,8 +384,7 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eset_current_stack: " + err);
         }
-        assertTrue("H5.H5Eset_current_stack: get_num - " + num_msg,
-                    num_msg == 3);
+        assertTrue("H5.H5Eset_current_stack: get_num - " + num_msg, num_msg == saved_num_msg);
     }
 
     @Test(expected = IllegalArgumentException.class)
@@ -395,8 +395,9 @@ public class TestH5Edefault {
     @Test
     public void testH5Epop() throws Throwable {
         long num_msg = -1;
+        long saved_num_msg = -1;
         try {
-            H5.H5Fopen("test", 0, 1);
+            H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
         }
         catch (Throwable err) {
         }
@@ -407,7 +408,8 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Epop: " + err);
         }
-        assertTrue("H5.H5Epop before #:" + num_msg, num_msg == 3);
+        assertTrue("H5.H5Epop before #:" + num_msg, num_msg > 0);
+        saved_num_msg = num_msg;
         try {
             H5.H5Epop(HDF5Constants.H5E_DEFAULT, 1);
             num_msg = H5.H5Eget_num(HDF5Constants.H5E_DEFAULT);
@@ -416,7 +418,7 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Epop: " + err);
         }
-        assertTrue("H5.H5Epop after #:" + num_msg, num_msg == 2);
+        assertTrue("H5.H5Epop after #:" + num_msg, num_msg == saved_num_msg - 1);
     }
 
     @Test(expected = IllegalArgumentException.class)
@@ -434,19 +436,28 @@ public class TestH5Edefault {
         H5.H5Eprint2(-1, null);
     }
 
-    @Test
+    @Ignore
     public void testH5EprintInt() {
-        try {
-            H5.H5Fopen("test", 0, 1);
-        }
-        catch (Throwable err) {
-        }
-        try {
-            H5.H5Eprint2(HDF5Constants.H5E_DEFAULT, null);
-        }
-        catch (Throwable err) {
-            err.printStackTrace();
-            fail("H5.H5EprintInt: " + err);
+        /*
+        * If HDF5_VOL_CONNECTOR is set, this might not be the
+        * native connector and the error stack might be different.
+        * Only check for the specific error stack if the native
+        * connector is being used.
+        */
+        String connector = System.getenv("HDF5_VOL_CONNECTOR");
+        if (connector == null) {
+            try {
+                H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
+            }
+            catch (Throwable err) {
+            }
+            try {
+                H5.H5Eprint2(HDF5Constants.H5E_DEFAULT, null);
+            }
+            catch (Throwable err) {
+                err.printStackTrace();
+                fail("H5.H5EprintInt: " + err);
+            }
         }
     }
 
@@ -481,7 +492,7 @@ public class TestH5Edefault {
     public void testH5Eclear2_with_msg() {
         long num_msg = -1;
         try {
-            H5.H5Fopen("test", 0, 1);
+            H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
         }
         catch (Throwable err) {
         }
@@ -492,8 +503,7 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eclear2_with_msg: " + err);
         }
-        assertTrue("H5.H5Eclear2_with_msg before #:" + num_msg,
-                    num_msg == 3);
+        assertTrue("H5.H5Eclear2_with_msg before #:" + num_msg, num_msg > 0);
         try {
             H5.H5Eclear2(HDF5Constants.H5E_DEFAULT);
             num_msg = H5.H5Eget_num(HDF5Constants.H5E_DEFAULT);
@@ -502,7 +512,7 @@ public class TestH5Edefault {
             err.printStackTrace();
             fail("H5.H5Eclear2_with_msg: " + err);
         }
-            assertTrue("H5.H5Eclear2_with_msg after #:" + num_msg, num_msg == 0);
+        assertTrue("H5.H5Eclear2_with_msg after #:" + num_msg, num_msg == 0);
     }
 
     @Test(expected = IllegalArgumentException.class)
@@ -545,7 +555,7 @@ public class TestH5Edefault {
     public void testH5Eget_num_with_msg() {
         long num_msg = -1;
         try {
-            H5.H5Fopen("test", 0, 1);
+            H5.H5Fopen("test", HDF5Constants.H5F_ACC_RDWR, HDF5Constants.H5P_DEFAULT);
         }
         catch (Throwable err) {
         }
@@ -560,3 +570,4 @@ public class TestH5Edefault {
     }
 
 }
+
