@@ -136,7 +136,7 @@
                        "%s \n",                                                                              \
                        (where), (int)__LINE__, __FILE__, x);                                                 \
         }                                                                                                    \
-        if (HDstrcmp(x, val) != 0) {                                                                         \
+        if (HDstrcmp(x, val)) {                                                                              \
             TestErrPrintf("*** UNEXPECTED VALUE from %s should be %s, but is %s at line %4d "                \
                           "in %s\n",                                                                         \
                           where, val, x, (int)__LINE__, __FILE__);                                           \
@@ -215,6 +215,7 @@ void test_attr(void);
 void test_select(void);
 void test_time(void);
 void test_reference(void);
+void test_reference_deprec(void);
 void test_vltypes(void);
 void test_vlstrings(void);
 void test_iterate(void);
@@ -238,6 +239,7 @@ void cleanup_attr(void);
 void cleanup_select(void);
 void cleanup_time(void);
 void cleanup_reference(void);
+void cleanup_reference_deprec(void);
 void cleanup_vltypes(void);
 void cleanup_vlstrings(void);
 void cleanup_iterate(void);
