@@ -32,18 +32,11 @@
 
  */
 
-#define H5S_FRIEND /*suppress error about including H5Spkg   */
-
-/* Define this macro to indicate that the testing APIs should be available */
-#define H5S_TESTING
-
-#include "hdf5.h"
 #include "H5private.h"
-#include "H5Spkg.h" /* Dataspaces                           */
 #include "testphdf5.h"
 
 static void coll_write_test(int chunk_factor);
-static void coll_read_test(int chunk_factor);
+static void coll_read_test(void);
 
 /*-------------------------------------------------------------------------
  * Function:    coll_irregular_cont_write
@@ -86,7 +79,7 @@ void
 coll_irregular_cont_read(void)
 {
 
-    coll_read_test(0);
+    coll_read_test();
 }
 
 /*-------------------------------------------------------------------------
@@ -130,7 +123,7 @@ void
 coll_irregular_simple_chunk_read(void)
 {
 
-    coll_read_test(1);
+    coll_read_test();
 }
 
 /*-------------------------------------------------------------------------
@@ -174,7 +167,7 @@ void
 coll_irregular_complex_chunk_read(void)
 {
 
-    coll_read_test(4);
+    coll_read_test();
 }
 
 /*-------------------------------------------------------------------------
@@ -214,9 +207,9 @@ coll_write_test(int chunk_factor)
     hsize_t block[2];  /* Block sizes */
     hsize_t chunk_dims[2];
 
-    herr_t   ret;
-    unsigned i;
-    int      fillvalue = 0; /* Fill value for the dataset */
+    herr_t ret;
+    int    i;
+    int    fillvalue = 0; /* Fill value for the dataset */
 
     int *matrix_out  = NULL;
     int *matrix_out1 = NULL; /* Buffer to read from the dataset */
@@ -251,7 +244,7 @@ coll_write_test(int chunk_factor)
     HDmemset(vector, 0, sizeof(int) * (size_t)mdim1[0] * (size_t)mpi_size);
     vector[0] = vector[MSPACE1_DIM * mpi_size - 1] = -1;
     for (i = 1; i < MSPACE1_DIM * mpi_size - 1; i++)
-        vector[i] = i;
+        H5_CHECKED_ASSIGN(vector[i], int, i, unsigned);
 
     /* Grab file access property list */
     facc_plist = create_faccess_plist(comm, info, facc_type);
@@ -651,7 +644,7 @@ coll_write_test(int chunk_factor)
  *-------------------------------------------------------------------------
  */
 static void
-coll_read_test(int chunk_factor)
+coll_read_test(void)
 {
 
     const char *filename;
@@ -670,7 +663,7 @@ coll_read_test(int chunk_factor)
     hsize_t block[2];  /* Block sizes */
     herr_t  ret;
 
-    unsigned i;
+    int i;
 
     int *matrix_out;
     int *matrix_out1; /* Buffer to read from the dataset */
@@ -849,6 +842,12 @@ coll_read_test(int chunk_factor)
     }
     VRFY((ret >= 0), "H5D contiguous irregular collective read succeed");
 
+    /*
+     * Free read buffers.
+     */
+    HDfree(matrix_out);
+    HDfree(matrix_out1);
+
     /*
      * Close memory file and memory dataspaces.
      */
@@ -903,8 +902,10 @@ coll_read_test(int chunk_factor)
 **
 ****************************************************************/
 
-#define LDSCT_DS_RANK                              5
+#define LDSCT_DS_RANK 5
+#if LOWER_DIM_SIZE_COMP_TEST__RUN_TEST__DEBUG
 #define LOWER_DIM_SIZE_COMP_TEST_DEBUG_TARGET_RANK 0
+#endif
 
 #define LOWER_DIM_SIZE_COMP_TEST__SELECT_CHECKER_BOARD__DEBUG 0
 
@@ -1460,38 +1461,40 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
     size_t      small_ds_size;
     size_t      small_ds_slice_size;
     size_t      large_ds_size;
-    size_t      large_ds_slice_size;
-    uint32_t    expected_value;
-    uint32_t *  small_ds_buf_0 = NULL;
-    uint32_t *  small_ds_buf_1 = NULL;
-    uint32_t *  large_ds_buf_0 = NULL;
-    uint32_t *  large_ds_buf_1 = NULL;
-    uint32_t *  ptr_0;
-    uint32_t *  ptr_1;
-    hsize_t     small_chunk_dims[LDSCT_DS_RANK];
-    hsize_t     large_chunk_dims[LDSCT_DS_RANK];
-    hsize_t     small_dims[LDSCT_DS_RANK];
-    hsize_t     large_dims[LDSCT_DS_RANK];
-    hsize_t     start[LDSCT_DS_RANK];
-    hsize_t     stride[LDSCT_DS_RANK];
-    hsize_t     count[LDSCT_DS_RANK];
-    hsize_t     block[LDSCT_DS_RANK];
-    hsize_t     small_sel_start[LDSCT_DS_RANK];
-    hsize_t     large_sel_start[LDSCT_DS_RANK];
-    hid_t       full_mem_small_ds_sid;
-    hid_t       full_file_small_ds_sid;
-    hid_t       mem_small_ds_sid;
-    hid_t       file_small_ds_sid;
-    hid_t       full_mem_large_ds_sid;
-    hid_t       full_file_large_ds_sid;
-    hid_t       mem_large_ds_sid;
-    hid_t       file_large_ds_sid;
-    hid_t       small_ds_dcpl_id = H5P_DEFAULT;
-    hid_t       large_ds_dcpl_id = H5P_DEFAULT;
-    hid_t       small_dataset; /* Dataset ID                   */
-    hid_t       large_dataset; /* Dataset ID                   */
-    htri_t      check;         /* Shape comparison return value */
-    herr_t      ret;           /* Generic return value */
+#if LOWER_DIM_SIZE_COMP_TEST__RUN_TEST__DEBUG
+    size_t large_ds_slice_size;
+#endif
+    uint32_t  expected_value;
+    uint32_t *small_ds_buf_0 = NULL;
+    uint32_t *small_ds_buf_1 = NULL;
+    uint32_t *large_ds_buf_0 = NULL;
+    uint32_t *large_ds_buf_1 = NULL;
+    uint32_t *ptr_0;
+    uint32_t *ptr_1;
+    hsize_t   small_chunk_dims[LDSCT_DS_RANK];
+    hsize_t   large_chunk_dims[LDSCT_DS_RANK];
+    hsize_t   small_dims[LDSCT_DS_RANK];
+    hsize_t   large_dims[LDSCT_DS_RANK];
+    hsize_t   start[LDSCT_DS_RANK];
+    hsize_t   stride[LDSCT_DS_RANK];
+    hsize_t   count[LDSCT_DS_RANK];
+    hsize_t   block[LDSCT_DS_RANK];
+    hsize_t   small_sel_start[LDSCT_DS_RANK];
+    hsize_t   large_sel_start[LDSCT_DS_RANK];
+    hid_t     full_mem_small_ds_sid;
+    hid_t     full_file_small_ds_sid;
+    hid_t     mem_small_ds_sid;
+    hid_t     file_small_ds_sid;
+    hid_t     full_mem_large_ds_sid;
+    hid_t     full_file_large_ds_sid;
+    hid_t     mem_large_ds_sid;
+    hid_t     file_large_ds_sid;
+    hid_t     small_ds_dcpl_id = H5P_DEFAULT;
+    hid_t     large_ds_dcpl_id = H5P_DEFAULT;
+    hid_t     small_dataset; /* Dataset ID                   */
+    hid_t     large_dataset; /* Dataset ID                   */
+    htri_t    check;         /* Shape comparison return value */
+    herr_t    ret;           /* Generic return value */
 
     MPI_Comm_size(MPI_COMM_WORLD, &mpi_size);
     MPI_Comm_rank(MPI_COMM_WORLD, &mpi_rank);
@@ -1511,9 +1514,10 @@ lower_dim_size_comp_test__run_test(const int chunk_edge_size, const hbool_t use_
     small_ds_size       = (size_t)((mpi_size + 1) * 1 * 1 * 10 * 10);
     small_ds_slice_size = (size_t)(1 * 1 * 10 * 10);
     large_ds_size       = (size_t)((mpi_size + 1) * 10 * 10 * 10 * 10);
-    large_ds_slice_size = (size_t)(10 * 10 * 10 * 10);
 
 #if LOWER_DIM_SIZE_COMP_TEST__RUN_TEST__DEBUG
+    large_ds_slice_size = (size_t)(10 * 10 * 10 * 10);
+
     if (mpi_rank == LOWER_DIM_SIZE_COMP_TEST_DEBUG_TARGET_RANK) {
         HDfprintf(stdout, "%s:%d: small ds size / slice size = %d / %d.\n", fcnName, mpi_rank,
                   (int)small_ds_size, (int)small_ds_slice_size);
