@@ -25,8 +25,12 @@
 #include "H5FDros3.h"
 #endif
 
-/* Global variables */
-unsigned           h5tools_nCols    = 80;
+/* global variables */
+unsigned h5tools_nCols = 80;
+/* ``get_option'' variables */
+int                opt_err = 1; /*get_option prints errors if this is on */
+int                opt_ind = 1; /*token pointer                          */
+const char *       opt_arg;     /*flag argument (or value)               */
 static int         h5tools_d_status = 0;
 static const char *h5tools_progname = "h5tools";
 
@@ -48,11 +52,11 @@ unsigned      outBuffOffset;
 FILE *        overflow_file = NULL;
 
 /* local functions */
-static void init_table(table_t **tbl);
+static void init_table(hid_t fid, table_t **tbl);
 #ifdef H5DUMP_DEBUG
-static void dump_table(char *tablename, table_t *table);
+static void dump_table(hid_t fid, char *tablename, table_t *table);
 #endif /* H5DUMP_DEBUG */
-static void add_obj(table_t *table, haddr_t objno, const char *objname, hbool_t recorded);
+static void add_obj(table_t *table, const H5O_token_t *obj_token, const char *objname, hbool_t recorded);
 
 /*-------------------------------------------------------------------------
  * Function: parallel_print
@@ -158,6 +162,167 @@ help_ref_msg(FILE *output)
     HDfprintf(output, "see the <%s> entry in the 'HDF5 Reference Manual'.\n", h5tools_getprogname());
 }
 
+/*-------------------------------------------------------------------------
+ * Function: get_option
+ *
+ * Purpose:  Determine the command-line options a user specified. We can
+ *           accept both short and long type command-lines.
+ *
+ * Return:  Success:    The short valued "name" of the command line
+ *              parameter or EOF if there are no more
+ *              parameters to process.
+ *
+ *          Failure:    A question mark.
+ *-------------------------------------------------------------------------
+ */
+int
+get_option(int argc, const char **argv, const char *opts, const struct long_options *l_opts)
+{
+    static int sp      = 1;   /* character index in current token */
+    int        opt_opt = '?'; /* option character passed back to user */
+
+    if (sp == 1) {
+        /* check for more flag-like tokens */
+        if (opt_ind >= argc || argv[opt_ind][0] != '-' || argv[opt_ind][1] == '\0') {
+            return EOF;
+        }
+        else if (HDstrcmp(argv[opt_ind], "--") == 0) {
+            opt_ind++;
+            return EOF;
+        }
+    }
+
+    if (sp == 1 && argv[opt_ind][0] == '-' && argv[opt_ind][1] == '-') {
+        /* long command line option */
+        int        i;
+        const char ch      = '=';
+        char *     arg     = HDstrdup(&argv[opt_ind][2]);
+        size_t     arg_len = 0;
+
+        opt_arg = strchr(&argv[opt_ind][2], ch);
+        arg_len = HDstrlen(&argv[opt_ind][2]);
+        if (opt_arg) {
+            arg_len -= HDstrlen(opt_arg);
+            opt_arg++; /* skip the equal sign */
+        }
+        arg[arg_len] = 0;
+
+        for (i = 0; l_opts && l_opts[i].name; i++) {
+            if (HDstrcmp(arg, l_opts[i].name) == 0) {
+                /* we've found a matching long command line flag */
+                opt_opt = l_opts[i].shortval;
+
+                if (l_opts[i].has_arg != no_arg) {
+                    if (opt_arg == NULL) {
+                        if (l_opts[i].has_arg != optional_arg) {
+                            if (opt_ind < (argc - 1))
+                                if (argv[opt_ind + 1][0] != '-')
+                                    opt_arg = argv[++opt_ind];
+                        }
+                        else if (l_opts[i].has_arg == require_arg) {
+                            if (opt_err)
+                                HDfprintf(rawerrorstream, "%s: option required for \"--%s\" flag\n", argv[0],
+                                          arg);
+
+                            opt_opt = '?';
+                        }
+                    }
+                }
+                else {
+                    if (opt_arg) {
+                        if (opt_err)
+                            HDfprintf(rawerrorstream, "%s: no option required for \"%s\" flag\n", argv[0],
+                                      arg);
+
+                        opt_opt = '?';
+                    }
+                }
+                break;
+            }
+        }
+
+        if (l_opts[i].name == NULL) {
+            /* exhausted all of the l_opts we have and still didn't match */
+            if (opt_err)
+                HDfprintf(rawerrorstream, "%s: unknown option \"%s\"\n", argv[0], arg);
+
+            opt_opt = '?';
+        }
+
+        opt_ind++;
+        sp = 1;
+
+        HDfree(arg);
+    }
+    else {
+        register char *cp; /* pointer into current token */
+
+        /* short command line option */
+        opt_opt = argv[opt_ind][sp];
+
+        if (opt_opt == ':' || (cp = HDstrchr(opts, opt_opt)) == 0) {
+            if (opt_err)
+                HDfprintf(rawerrorstream, "%s: unknown option \"%c\"\n", argv[0], opt_opt);
+
+            /* if no chars left in this token, move to next token */
+            if (argv[opt_ind][++sp] == '\0') {
+                opt_ind++;
+                sp = 1;
+            }
+            return '?';
+        }
+
+        if (*++cp == ':') {
+            /* if a value is expected, get it */
+            if (argv[opt_ind][sp + 1] != '\0') {
+                /* flag value is rest of current token */
+                opt_arg = &argv[opt_ind++][sp + 1];
+            }
+            else if (++opt_ind >= argc) {
+                if (opt_err)
+                    HDfprintf(rawerrorstream, "%s: value expected for option \"%c\"\n", argv[0], opt_opt);
+
+                opt_opt = '?';
+            }
+            else {
+                /* flag value is next token */
+                opt_arg = argv[opt_ind++];
+            }
+
+            sp = 1;
+        }
+        /* wildcard argument */
+        else if (*cp == '*') {
+            /* check the next argument */
+            opt_ind++;
+            /* we do have an extra argument, check if not last */
+            if ((opt_ind + 1) < argc) {
+                if (argv[opt_ind][0] != '-') {
+                    opt_arg = argv[opt_ind++];
+                }
+                else {
+                    opt_arg = NULL;
+                }
+            }
+            else {
+                opt_arg = NULL;
+            }
+        }
+        else {
+            /* set up to look at next char in token, next time */
+            if (argv[opt_ind][++sp] == '\0') {
+                /* no more in current token, so setup next token */
+                opt_ind++;
+                sp = 1;
+            }
+            opt_arg = NULL;
+        }
+    }
+
+    /* return the current flag character found */
+    return opt_opt;
+}
+
 /*****************************************************************************
  *
  * Function: parse_tuple()
@@ -418,10 +583,11 @@ print_version(const char *progname)
  *-------------------------------------------------------------------------
  */
 static void
-init_table(table_t **tbl)
+init_table(hid_t fid, table_t **tbl)
 {
     table_t *table = (table_t *)HDmalloc(sizeof(table_t));
 
+    table->fid   = fid;
     table->size  = 20;
     table->nobjs = 0;
     table->objs  = (obj_t *)HDmalloc(table->size * sizeof(obj_t));
@@ -449,7 +615,6 @@ free_table(table_t *table)
             HDfree(table->objs[u].objname);
 
     HDfree(table->objs);
-    HDfree(table);
 }
 
 #ifdef H5DUMP_DEBUG
@@ -463,14 +628,20 @@ free_table(table_t *table)
  *-------------------------------------------------------------------------
  */
 static void
-dump_table(char *tablename, table_t *table)
+dump_table(hid_t fid, char *tablename, table_t *table)
 {
     unsigned u;
+    char *   obj_tok_str = NULL;
 
     PRINTSTREAM(rawoutstream, "%s: # of entries = %d\n", tablename, table->nobjs);
-    for (u = 0; u < table->nobjs; u++)
-        PRINTSTREAM(rawoutstream, "%a %s %d %d\n", table->objs[u].objno, table->objs[u].objname,
+    for (u = 0; u < table->nobjs; u++) {
+        H5VLconnector_token_to_str(fid, table->objs[u].obj_token, &obj_tok_str);
+
+        PRINTSTREAM(rawoutstream, "%s %s %d %d\n", obj_tok_str, table->objs[u].objname,
                     table->objs[u].displayed, table->objs[u].recorded);
+
+        H5VLfree_token_str(fid, obj_tok_str);
+    }
 }
 
 /*-------------------------------------------------------------------------
@@ -484,9 +655,9 @@ dump_table(char *tablename, table_t *table)
 void
 dump_tables(find_objs_t *info)
 {
-    dump_table("group_table", info->group_table);
-    dump_table("dset_table", info->dset_table);
-    dump_table("type_table", info->type_table);
+    dump_table(info->fid, "group_table", info->group_table);
+    dump_table(info->fid, "dset_table", info->dset_table);
+    dump_table(info->fid, "type_table", info->type_table);
 }
 #endif /* H5DUMP_DEBUG */
 
@@ -501,13 +672,17 @@ dump_tables(find_objs_t *info)
  *-------------------------------------------------------------------------
  */
 H5_ATTR_PURE obj_t *
-             search_obj(table_t *table, haddr_t objno)
+             search_obj(table_t *table, const H5O_token_t *obj_token)
 {
     unsigned u;
+    int      token_cmp;
 
-    for (u = 0; u < table->nobjs; u++)
-        if (table->objs[u].objno == objno)
+    for (u = 0; u < table->nobjs; u++) {
+        if (H5Otoken_cmp(table->fid, &table->objs[u].obj_token, obj_token, &token_cmp) < 0)
+            return NULL;
+        if (!token_cmp)
             return &(table->objs[u]);
+    }
 
     return NULL;
 }
@@ -523,7 +698,7 @@ H5_ATTR_PURE obj_t *
  *-------------------------------------------------------------------------
  */
 static herr_t
-find_objs_cb(const char *name, const H5O_info_t *oinfo, const char *already_seen, void *op_data)
+find_objs_cb(const char *name, const H5O_info2_t *oinfo, const char *already_seen, void *op_data)
 {
     find_objs_t *info      = (find_objs_t *)op_data;
     herr_t       ret_value = 0;
@@ -531,7 +706,7 @@ find_objs_cb(const char *name, const H5O_info_t *oinfo, const char *already_seen
     switch (oinfo->type) {
         case H5O_TYPE_GROUP:
             if (NULL == already_seen)
-                add_obj(info->group_table, oinfo->addr, name, TRUE);
+                add_obj(info->group_table, &oinfo->token, name, TRUE);
             break;
 
         case H5O_TYPE_DATASET:
@@ -539,18 +714,18 @@ find_objs_cb(const char *name, const H5O_info_t *oinfo, const char *already_seen
                 hid_t dset = H5I_INVALID_HID;
 
                 /* Add the dataset to the list of objects */
-                add_obj(info->dset_table, oinfo->addr, name, TRUE);
+                add_obj(info->dset_table, &oinfo->token, name, TRUE);
 
                 /* Check for a dataset that uses a named datatype */
                 if ((dset = H5Dopen2(info->fid, name, H5P_DEFAULT)) >= 0) {
                     hid_t type = H5Dget_type(dset);
 
                     if (H5Tcommitted(type) > 0) {
-                        H5O_info_t type_oinfo;
+                        H5O_info2_t type_oinfo;
 
-                        H5Oget_info2(type, &type_oinfo, H5O_INFO_BASIC);
-                        if (search_obj(info->type_table, type_oinfo.addr) == NULL)
-                            add_obj(info->type_table, type_oinfo.addr, name, FALSE);
+                        H5Oget_info3(type, &type_oinfo, H5O_INFO_BASIC);
+                        if (search_obj(info->type_table, &type_oinfo.token) == NULL)
+                            add_obj(info->type_table, &type_oinfo.token, name, FALSE);
                     } /* end if */
 
                     H5Tclose(type);
@@ -565,8 +740,8 @@ find_objs_cb(const char *name, const H5O_info_t *oinfo, const char *already_seen
             if (NULL == already_seen) {
                 obj_t *found_obj;
 
-                if ((found_obj = search_obj(info->type_table, oinfo->addr)) == NULL)
-                    add_obj(info->type_table, oinfo->addr, name, TRUE);
+                if ((found_obj = search_obj(info->type_table, &oinfo->token)) == NULL)
+                    add_obj(info->type_table, &oinfo->token, name, TRUE);
                 else {
                     /* Use latest version of name */
                     HDfree(found_obj->objname);
@@ -578,6 +753,7 @@ find_objs_cb(const char *name, const H5O_info_t *oinfo, const char *already_seen
             }     /* end if */
             break;
 
+        case H5O_TYPE_MAP:
         case H5O_TYPE_UNKNOWN:
         case H5O_TYPE_NTYPES:
         default:
@@ -603,9 +779,9 @@ init_objs(hid_t fid, find_objs_t *info, table_t **group_table, table_t **dset_ta
     herr_t ret_value = SUCCEED;
 
     /* Initialize the tables */
-    init_table(group_table);
-    init_table(dset_table);
-    init_table(type_table);
+    init_table(fid, group_table);
+    init_table(fid, dset_table);
+    init_table(fid, type_table);
 
     /* Init the find_objs_t */
     info->fid         = fid;
@@ -640,7 +816,7 @@ done:
  *-------------------------------------------------------------------------
  */
 static void
-add_obj(table_t *table, haddr_t objno, const char *objname, hbool_t record)
+add_obj(table_t *table, const H5O_token_t *obj_token, const char *objname, hbool_t record)
 {
     size_t u;
 
@@ -654,7 +830,7 @@ add_obj(table_t *table, haddr_t objno, const char *objname, hbool_t record)
     u = table->nobjs++;
 
     /* Set information about object */
-    table->objs[u].objno     = objno;
+    HDmemcpy(&table->objs[u].obj_token, obj_token, sizeof(H5O_token_t));
     table->objs[u].objname   = HDstrdup(objname);
     table->objs[u].recorded  = record;
     table->objs[u].displayed = 0;
@@ -703,11 +879,11 @@ int
 H5tools_get_symlink_info(hid_t file_id, const char *linkpath, h5tool_link_info_t *link_info,
                          hbool_t get_obj_type)
 {
-    htri_t     l_ret;
-    H5O_info_t trg_oinfo;
-    hid_t      fapl      = H5P_DEFAULT;
-    hid_t      lapl      = H5P_DEFAULT;
-    int        ret_value = -1; /* init to fail */
+    htri_t      l_ret;
+    H5O_info2_t trg_oinfo;
+    hid_t       fapl      = H5P_DEFAULT;
+    hid_t       lapl      = H5P_DEFAULT;
+    int         ret_value = -1; /* init to fail */
 
     /* init */
     link_info->trg_type = H5O_TYPE_UNKNOWN;
@@ -726,7 +902,7 @@ H5tools_get_symlink_info(hid_t file_id, const char *linkpath, h5tool_link_info_t
     } /* end if */
 
     /* get info from link */
-    if (H5Lget_info(file_id, linkpath, &(link_info->linfo), H5P_DEFAULT) < 0) {
+    if (H5Lget_info2(file_id, linkpath, &(link_info->linfo), H5P_DEFAULT) < 0) {
         if (link_info->opt.msg_mode == 1)
             parallel_print("Warning: unable to get link info from <%s>\n", linkpath);
         H5TOOLS_GOTO_DONE(FAIL);
@@ -783,7 +959,7 @@ H5tools_get_symlink_info(hid_t file_id, const char *linkpath, h5tool_link_info_t
         }
 
         /* get target object info */
-        if (H5Oget_info_by_name2(file_id, linkpath, &trg_oinfo, H5O_INFO_BASIC, lapl) < 0) {
+        if (H5Oget_info_by_name3(file_id, linkpath, &trg_oinfo, H5O_INFO_BASIC, lapl) < 0) {
             if (link_info->opt.msg_mode == 1)
                 parallel_print("Warning: unable to get object information for <%s>\n", linkpath);
             H5TOOLS_GOTO_DONE(FAIL);
@@ -797,8 +973,8 @@ H5tools_get_symlink_info(hid_t file_id, const char *linkpath, h5tool_link_info_t
         } /* end if */
 
         /* set target obj type to return */
+        HDmemcpy(&link_info->obj_token, &trg_oinfo.token, sizeof(H5O_token_t));
         link_info->trg_type = trg_oinfo.type;
-        link_info->objno    = trg_oinfo.addr;
         link_info->fileno   = trg_oinfo.fileno;
     } /* end if */
     else
@@ -955,7 +1131,7 @@ done:
  *
  * Return:
  *
- *     FAIL if...
+ *     0 (failure) if...
  *         * Read-Only S3 VFD is not enabled.
  *         * NULL fapl pointer: (NULL, {...} )
  *         * Warning: In all cases below, fapl will be set as "default"
@@ -972,7 +1148,7 @@ done:
  *                 * (&fa, {"...", "",    "...")
  *             * Any string would overflow allowed space in fapl definition.
  *     or
- *     SUCCEED
+ *     1 (success)
  *         * Sets components in fapl_t pointer, copying strings as appropriate.
  *         * "Default" fapl (valid version, authenticate->False, empty strings)
  *             * `values` pointer is NULL
@@ -989,46 +1165,112 @@ done:
  *
  *----------------------------------------------------------------------------
  */
-herr_t
+int
 h5tools_populate_ros3_fapl(H5FD_ros3_fapl_t *fa, const char **values)
 {
-    herr_t ret_value = SUCCEED;
+    int show_progress = 0; /* set to 1 for debugging */
+    int ret_value     = 1; /* 1 for success, 0 for failure           */
+                           /* e.g.? if (!populate()) { then failed } */
 
-    if (fa == NULL)
-        H5TOOLS_GOTO_ERROR(FAIL, "fa cannot be NULL");
+    if (show_progress) {
+        HDprintf("called h5tools_populate_ros3_fapl\n");
+    }
 
+    if (fa == NULL) {
+        if (show_progress) {
+            HDprintf("  ERROR: null pointer to fapl_t\n");
+        }
+        ret_value = 0;
+        goto done;
+    }
+
+    if (show_progress) {
+        HDprintf("  preset fapl with default values\n");
+    }
     fa->version       = H5FD_CURR_ROS3_FAPL_T_VERSION;
     fa->authenticate  = FALSE;
     *(fa->aws_region) = '\0';
     *(fa->secret_id)  = '\0';
     *(fa->secret_key) = '\0';
 
-    /* Sanity checks */
+    /* sanity-check supplied values
+     */
     if (values != NULL) {
-        if (values[0] == NULL || values[1] == NULL || values[2] == NULL)
-            H5TOOLS_GOTO_ERROR(FAIL, "values data cannot be NULL");
+        if (values[0] == NULL) {
+            if (show_progress) {
+                HDprintf("  ERROR: aws_region value cannot be NULL\n");
+            }
+            ret_value = 0;
+            goto done;
+        }
+        if (values[1] == NULL) {
+            if (show_progress) {
+                HDprintf("  ERROR: secret_id value cannot be NULL\n");
+            }
+            ret_value = 0;
+            goto done;
+        }
+        if (values[2] == NULL) {
+            if (show_progress) {
+                HDprintf("  ERROR: secret_key value cannot be NULL\n");
+            }
+            ret_value = 0;
+            goto done;
+        }
 
         /* if region and ID are supplied (key optional), write to fapl...
          * fail if value would overflow
          */
         if (*values[0] != '\0' && *values[1] != '\0') {
-            if (HDstrlen(values[0]) > H5FD_ROS3_MAX_REGION_LEN)
-                H5TOOLS_GOTO_ERROR(FAIL, "can't exceed max region length");
+            if (HDstrlen(values[0]) > H5FD_ROS3_MAX_REGION_LEN) {
+                if (show_progress) {
+                    HDprintf("  ERROR: aws_region value too long\n");
+                }
+                ret_value = 0;
+                goto done;
+            }
             HDmemcpy(fa->aws_region, values[0], (HDstrlen(values[0]) + 1));
+            if (show_progress) {
+                HDprintf("  aws_region set\n");
+            }
 
-            if (HDstrlen(values[1]) > H5FD_ROS3_MAX_SECRET_ID_LEN)
-                H5TOOLS_GOTO_ERROR(FAIL, "can't exceed max secret ID length");
+            if (HDstrlen(values[1]) > H5FD_ROS3_MAX_SECRET_ID_LEN) {
+                if (show_progress) {
+                    HDprintf("  ERROR: secret_id value too long\n");
+                }
+                ret_value = 0;
+                goto done;
+            }
             HDmemcpy(fa->secret_id, values[1], (HDstrlen(values[1]) + 1));
+            if (show_progress) {
+                HDprintf("  secret_id set\n");
+            }
 
-            if (HDstrlen(values[2]) > H5FD_ROS3_MAX_SECRET_KEY_LEN)
-                H5TOOLS_GOTO_ERROR(FAIL, "can't exceed max secret key length");
+            if (HDstrlen(values[2]) > H5FD_ROS3_MAX_SECRET_KEY_LEN) {
+                if (show_progress) {
+                    HDprintf("  ERROR: secret_key value too long\n");
+                }
+                ret_value = 0;
+                goto done;
+            }
             HDmemcpy(fa->secret_key, values[2], (HDstrlen(values[2]) + 1));
+            if (show_progress) {
+                HDprintf("  secret_key set\n");
+            }
 
             fa->authenticate = TRUE;
+            if (show_progress) {
+                HDprintf("  set to authenticate\n");
+            }
         }
-        else if (*values[0] != '\0' || *values[1] != '\0' || *values[2] != '\0')
-            H5TOOLS_GOTO_ERROR(FAIL, "all values cannot be empty strings");
-    }
+        else if (*values[0] != '\0' || *values[1] != '\0' || *values[2] != '\0') {
+            if (show_progress) {
+                HDprintf("  ERROR: invalid assortment of empty/non-empty values\n");
+            }
+            ret_value = 0;
+            goto done;
+        }
+    } /* values != NULL */
 
 done:
     return ret_value;
